Module streamer

Module streamer 

The Streamer continuously consumes data points and produces models.

This module also provides the stdio function that builds a point iterator which reads the standard input and a write closure that writes to the standard output.

Structs

Streamer
Reads data from In and writes model to Out.

Functions

channels
Returns point iterator / model writer that use mpsc channels.
stdio
Returns point iterator / model writer that use standard in out.