Module fluent_data::model
source · [−]Expand description
The Model struct represents the set of balls model.
The model can be loaded with existing balls by the Model::load method. It can also be used to predict the balls that most probably contains a given point by using the Model::predict method.