The Streamer continuously consumes data points and produces models.
This module also provides the stdio function that builds a point iterator which reads the standard input and a write closure that writes to the standard output.
In
Out